home · contact · privacy
Derive legal geometries directly from Map class names.
[plomrogue2-experiments] / client.py
index fb88c7e7439e99c89d17cdf14523e192d3c79492..11d33ccaba367f06d0a70cba78fd14dd662823a9 100755 (executable)
--- a/client.py
+++ b/client.py
@@ -4,47 +4,79 @@ import plom_socket_io
 import socket
 import threading
 from parser import ArgError, Parser
-from game_common import World
+import game_common
 
 
-class Thing:
-    def __init__(self, id_, position, symbol):
-        self.id_ = id_
-        self.symbol = symbol
-        self.position = position
+class MapSquare(game_common.Map):
 
-class Game:
-    world = World()
-    log_text = ''
+    def list_terrain_to_lines(self, terrain_as_list):
+        terrain = ''.join(terrain_as_list)
+        map_lines = []
+        start_cut = 0
+        while start_cut < len(terrain):
+            limit = start_cut + self.game.world.map_.size[1]
+            map_lines += [terrain[start_cut:limit]]
+            start_cut = limit
+        return "\n".join(map_lines)
+
+
+class MapHex(game_common.Map):
+
+    def list_terrain_to_lines(self, terrain_as_list):
+        new_terrain_list = []
+        x = 0
+        y = 0
+        for c in terrain_as_list:
+            new_terrain_list += [c, ' ']
+            x += 1
+            if x == self.size[1]:
+                new_terrain_list += ['\n']
+                x = 0
+                y += 1
+                if y % 2 != 0:
+                    new_terrain_list += [' ']
+        return ''.join(new_terrain_list)
+
+
+map_manager = game_common.MapManager(globals())
+
+
+class World(game_common.World):
+
+    def __init__(self, game, *args, **kwargs):
+        """Extend original with local classes and empty default map.
+
+        We need the empty default map because we draw the map widget
+        on any update, even before we actually receive map data.
+        """
+        super().__init__(*args, **kwargs)
+        self.game = game
+        self.map_ = self.game.map_manager.get_map_class('Hex')()
+
+
+class Game(game_common.CommonCommandsMixin):
+
+    def __init__(self):
+        self.map_manager = map_manager
+        self.world = World(self)
+        self.log_text = ''
 
     def log(self, msg):
         """Prefix msg plus newline to self.log_text."""
         self.log_text = msg + '\n' + self.log_text
 
-    def cmd_THING_TYPE(self, i, type_):
-        t = self.world.get_thing(i)
+    def symbol_for_type(self, type_):
         symbol = '?'
         if type_ == 'human':
             symbol = '@'
         elif type_ == 'monster':
             symbol = 'm'
-        t.symbol = symbol
-    cmd_THING_TYPE.argtypes = 'int:nonneg string'
+        return symbol
 
-    def cmd_THING_POS(self, i, yx):
-        t = self.world.get_thing(i)
-        t.position = list(yx)
-    cmd_THING_POS.argtypes = 'int:nonneg yx_tuple:nonneg'
-
-    def cmd_THING_POS(self, i, yx):
-        t = self.world.get_thing(i)
-        t.position = list(yx)
-    cmd_THING_POS.argtypes = 'int:nonneg yx_tuple:nonneg'
-
-    def cmd_MAP_SIZE(self, yx):
-        """Set self.map_size to yx, redraw self.terrain_map as '?' cells."""
-        self.world.set_map_size(yx)
-    cmd_MAP_SIZE.argtypes = 'yx_tuple:nonneg'
+    def cmd_LAST_PLAYER_TASK_RESULT(self, msg):
+        if msg != "success":
+            self.log_text = msg + '\n' + self.log_text
+    cmd_LAST_PLAYER_TASK_RESULT.argtypes = 'string'
 
     def cmd_TURN_FINISHED(self, n):
         """Do nothing. (This may be extended later.)"""
@@ -57,9 +89,9 @@ class Game:
         self.world.things = []
     cmd_NEW_TURN.argtypes = 'int:nonneg'
 
-    def cmd_TERRAIN_LINE(self, y, terrain_line):
-        self.world.set_map_line(y, terrain_line)
-    cmd_TERRAIN_LINE.argtypes = 'int:nonneg string'
+    def cmd_VISIBLE_MAP_LINE(self, y, terrain_line):
+        self.world.map_.set_line(y, terrain_line)
+    cmd_VISIBLE_MAP_LINE.argtypes = 'int:nonneg string'
 
 
 class WidgetManager:
@@ -77,19 +109,12 @@ class WidgetManager:
         self.top = urwid.Filler(widget_pile, valign='top')
 
     def draw_map(self):
-        """Draw map view from .game.terrain_map, .game.things."""
-        map_lines = []
-        map_size = len(self.game.world.terrain_map)
-        start_cut = 0
-        while start_cut < map_size:
-            limit = start_cut + self.game.world.map_size[1]
-            map_lines += [self.game.world.terrain_map[start_cut:limit]]
-            start_cut = limit
+        """Draw map view from .game.map_.terrain, .game.things."""
+        terrain_as_list = list(self.game.world.map_.terrain[:])
         for t in self.game.world.things:
-            line_as_list = list(map_lines[t.position[0]])
-            line_as_list[t.position[1]] = t.symbol
-            map_lines[t.position[0]] = ''.join(line_as_list)
-        return "\n".join(map_lines)
+            pos_i = self.game.world.map_.get_position_index(t.position)
+            terrain_as_list[pos_i] = self.game.symbol_for_type(t.type_)
+        return self.game.world.map_.list_terrain_to_lines(terrain_as_list)
 
     def update(self):
         """Redraw all non-edit widgets."""